==> vesper-0.4.8.tar.gz: vesper-0.4.8/README.md <==
Vesper
======

## Overview

Vesper is open source software for acoustic monitoring of nocturnal bird
migration.

Vesper aims to enable a wide range of users, including both bird enthusiasts
and professional ornithologists, to collaboratively collect, view, and
analyze nocturnal flight calls (NFCs) of migratory birds at a wide range of
project scales.

Vesper is a web application. As such, it comprises two parts, a
*server* and a *client*. The server stores and processes audio data
and metadata while the client runs in a web browser to provide the
user interface. The server and client can run on the same computer
for personal or small group use, or the server can run on a separate
computer and serve multiple clients for larger deployments.

## Installation
Vesper is not ready for widespread use just yet, but for the intrepid
there are preliminary
[installation instructions](https://github.com/HaroldMills/Vesper/wiki/Installing-Vesper).

## Licensing and Acknowledgments

Vesper is provided under the
[MIT License](https://github.com/HaroldMills/Vesper/blob/master/LICENSE).

[BirdVoxDetect](https://github.com/BirdVox/birdvoxdetect) is provided by the
[BirdVox](https://wp.nyu.edu/birdvox/) project under the
[MIT License](https://github.com/BirdVox/birdvoxdetect/blob/master/LICENSE).

BirdVoxDetect is described in:

**[Robust Sound Event Detection in Bioacoustic Sensor Networks](https://journals.plos.org/plosone/article/file?id=10.1371/journal.pone.0214168&type=printable)**<br/>
Vincent Lostanlen, Justin Salamon, Andrew Farnsworth, Steve Kelling, and Juan Pablo Bello<br/>
PLoS ONE 14(10): e0214168, 2019. DOI: https://doi.org/10.1371/journal.pone.0214168

Many thanks to [MPG Ranch](http://mpgranch.com), Project Night Flight, [Old Bird](http://oldbird.org), and anonymous donors for financial support of the Vesper project.

![Image of Zenodo DOI badge](https://zenodo.org/badge/DOI/10.5281/zenodo.1020572.svg)

==> vesper-0.4.11.tar.gz: vesper-0.4.11/README.md <==
Vesper
======

## Overview

Vesper is open source software for acoustic monitoring of nocturnal bird
migration.

Vesper aims to enable a wide range of users, including both bird enthusiasts
and professional ornithologists, to collaboratively collect, view, and
analyze nocturnal flight calls (NFCs) of migratory birds at a wide range of
project scales.

Vesper is a web application. As such, it comprises two parts, a
*server* and a *client*. The server stores and processes audio data
and metadata while the client runs in a web browser to provide the
user interface. The server and client can run on the same computer
for personal or small group use, or the server can run on a separate
computer and serve multiple clients for larger deployments.

## Installation
Vesper is not yet ready for widespread use, but for the intrepid
there are preliminary
[installation instructions](https://vesper.readthedocs.io/en/latest/installation.html).

## Licensing and Acknowledgments

Vesper is provided under the
[MIT License](https://github.com/HaroldMills/Vesper/blob/master/LICENSE).

Many thanks to [MPG Ranch](http://mpgranch.com), Project Night Flight, [Old Bird](http://oldbird.org), and anonymous donors for financial support of the Vesper project.

Vesper's favicon is [Moon And Birds](https://thenounproject.com/icon/moon-and-birds-281583/) by [Vectors Market](https://thenounproject.com/vectorsmarket/), obtained from [Noun Project](https://thenounproject.com/).

![Image of Zenodo DOI badge](https://zenodo.org/badge/DOI/10.5281/zenodo.1020572.svg)
